# -*- coding: utf-8 -*-

# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

#
# UTAH documentation build configuration file, created by
# sphinx-quickstart on Tue Aug  7 18:05:11 2012.
#
# This file is execfile()d with the current directory set to its containing
# dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

"""Provide documentation configuration."""


import itertools
import os
import re
import sys

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
sys.path.insert(0, os.path.abspath('../..'))
sys.path.insert(0, os.path.abspath('../../examples'))
sys.path.insert(0, os.path.abspath('../../utah/client'))


class ModuleMock(object):

    """Mock class to avoid import errors."""

    def __init__(self, name):
        self.__name__ = name

    def __getattr__(self, name):
        full_name = '{0}.{1}'.format(self.__name__, name)

        # Submodules are returned if they exist
        if full_name in sys.modules:
            return sys.modules[full_name]

        # Members that start with an upper case letter
        # are expected to be a class
        if name[0].isupper():
            obj = ClassMock
        # otherwise, they are assumed to be a function
        else:
            # The value returned by the function isn't relevant when is mocked
            # unless it's decorator (addressed by the implementation below)
            def function(*args, **kwargs):
                def _function(*args, **kwargs):
                    return args[0]
                return _function

            obj = function
        obj.__name__ = full_name
        return obj


class ClassMock(object):

    """Mock class to avoid import errors."""

    def __init__(self, *args, **kwargs):
        pass


# Mock all third party modules not available in the readthedocs.org environment
# Note that in a development environment where the modules are available, they
# are not mocked to make it possible to run the doctests correctly.
for mod_name in ('psutil', 'yaml', 'paramiko', 'jsonschema', 'libvirt',
                 'bzrlib', 'bzrlib.builtins', 'bzrlib.plugin', 'bzrlib.errors',
                 'apt', 'apt.cache', 'netifaces'):
    try:
        sys.modules[mod_name] = __import__(mod_name)
    except (ImportError, RuntimeError):
        sys.modules[mod_name] = ModuleMock(mod_name)


def get_parser_strings(script_name, parser):
    """Autogenerate help contents for manual pages when building them.

    :returns: description, options, and epilog
    :rtype: tuple

    """
    description = parser.description

    help_lines = parser.format_help().splitlines()
    options_lines = itertools.dropwhile(
        lambda l: l != 'optional arguments:',
        help_lines)  # Drop usage
    options_lines = itertools.takewhile(
        lambda l: bool(l),
        options_lines)  # Drop epilog
    options_lines.next()  # Drop first line

    def fix_line(line):
        """Format argparse output.

        Remove indentation and replace curly braces with angle brackets to
        match the expected format.

        """
        line = line[2:]

        # Apply changes only to option lines,
        # not the ones with the help text
        if line.startswith('-'):
            line = line.replace('{', '<')
            line = line.replace('}', '>')
        return line

    options_lines = [fix_line(line) for line in options_lines]
    options = '\n'.join(options_lines)

    if parser.epilog is None:
        epilog = ''
    else:
        # Highlight program name and options
        epilog = parser.epilog % {'prog': '**%s**' % script_name}
        epilog = re.sub(r'(-\w)', r'**\1**', epilog)

        # Duplicate backslashes to avoid dropping them
        # because of the rst formatting
        epilog = re.sub(r'\\', r'\\\\', epilog)

        # Drop 'For example:'
        epilog = '\n'.join(epilog.splitlines()[1:])

        # Use line blocks to preserve line breaks
        # Make sure that block is in a separate paragraph
        epilog = re.sub(r'^\t', '\n| ', epilog, flags=re.M, count=1)
        epilog = re.sub(r'^\t', '| ', epilog, flags=re.M)

    return description, options, epilog


def generate_usage(module_name, parser_func):
    # Generate file being included in the introduction
    module = __import__(module_name)
    orig = sys.argv[0]
    sys.argv[0] = '{}.py'.format(module_name)
    parser = getattr(module, parser_func)()
    filename = '{}.txt'.format(module_name)
    with open(filename, 'w') as f:
        lines = ['    {}'.format(line)
                 for line in parser.format_help().splitlines()]
        lines.insert(0, '::\n\n')
        f.write('\n'.join(lines))
    sys.argv[0] = orig

generate_usage('run_utah_tests', 'get_parser')
generate_usage('run_utah_phablet', '_get_parser')

# Generate files included by man pages
module_and_script_names = (
    ('client', 'utah'),
    ('run_utah_tests', 'run_utah_tests.py'),
    ('phoenix', 'phoenix'),
)
for module_name, script_name in module_and_script_names:
    module = __import__(module_name)
    parser = module.get_parser()
    description, options, epilog = get_parser_strings(script_name, parser)

    for section_name in ('description', 'options', 'epilog'):
        section = locals()[section_name]
        filename = 'man/{}_{}.txt'.format(module_name, section_name)
        with open(filename, 'w') as f:
            f.write(section)

# -- General configuration ----------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = ['sphinx.ext.autodoc',  # Include documentation from docstrings
              'sphinx.ext.viewcode',  # Add links to highlight source code
              'sphinx.ext.doctest',  # Test snippets in the documentation
              ]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The encoding of source files.
#source_encoding = 'utf-8-sig'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'UTAH'
copyright = u'2012, Canonical Ltd'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = 'dev'
# The full version, including alpha/beta/rc tags.
release = 'dev'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#language = None

# There are two options for replacing |today|: either, you set today to some
# non-false value, then it is used:
#today = ''
# Else, today_fmt is used as the format for a strftime call.
#today_fmt = '%B %d, %Y'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = []

# The reST default role (used for this markup: `text`) to use for all
# documents.
#default_role = None

# If true, '()' will be appended to :func: etc. cross-reference text.
#add_function_parentheses = True

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
#add_module_names = True

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
#show_authors = False

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# A list of ignored prefixes for module index sorting.
#modindex_common_prefix = []


# -- Options for HTML output --------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = 'default'

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#html_theme_options = {}

# Add any paths that contain custom themes here, relative to this directory.
#html_theme_path = []

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
#html_title = None

# A shorter title for the navigation bar.  Default is the same as html_title.
#html_short_title = None

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
#html_logo = None

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
#html_favicon = None

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
#html_last_updated_fmt = '%b %d, %Y'

# If true, SmartyPants will be used to convert quotes and dashes to
# typographically correct entities.
#html_use_smartypants = True

# Custom sidebar templates, maps document names to template names.
#html_sidebars = {}

# Additional templates that should be rendered to pages, maps page names to
# template names.
#html_additional_pages = {}

# If false, no module index is generated.
#html_domain_indices = True

# If false, no index is generated.
#html_use_index = True

# If true, the index is split into individual pages for each letter.
#html_split_index = False

# If true, links to the reST sources are added to the pages.
#html_show_sourcelink = True

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
#html_show_sphinx = True

# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
#html_show_copyright = True

# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it.  The value of this option must be the
# base URL from which the finished HTML is served.
#html_use_opensearch = ''

# This is the file name suffix for HTML files (e.g. ".xhtml").
#html_file_suffix = None

# Output file base name for HTML help builder.
htmlhelp_basename = 'UTAHdoc'


# -- Options for LaTeX output -------------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #'preamble': '',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author,
#  documentclass [howto/manual]).
latex_documents = [
    ('index', 'UTAH.tex', u'UTAH Documentation',
     u'Canonical Ltd', 'manual'),
]

# The name of an image file (relative to this directory) to place at the top of
# the title page.
#latex_logo = None

# For "manual" documents, if this is true, then toplevel headings are parts,
# not chapters.
#latex_use_parts = False

# If true, show page references after internal links.
#latex_show_pagerefs = False

# If true, show URL addresses after external links.
#latex_show_urls = False

# Documents to append as an appendix to all manuals.
#latex_appendices = []

# If false, no module index is generated.
#latex_domain_indices = True


# -- Options for manual page output -------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    ('man/utah', 'utah', u'UTAH client test runner',
     [u'Canonical Ltd'], 1),
    ('man/run_utah_tests.py', 'run_utah_tests.py',
     u'UTAH server test runner (any hardware)', [u'Canonical Ltd'], 1),
    ('man/phoenix', 'phoenix',
     u'Phoenix bootstrapper', [u'Canonical Ltd'], 1),
]

# If true, show URL addresses after external links.
#man_show_urls = False


# -- Options for Texinfo output -----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    ('index', 'UTAH', u'UTAH Documentation',
     u'Canonical Ltd', 'UTAH', 'One line description of project.',
     'Miscellaneous'),
]

# Documents to append as an appendix to all manuals.
#texinfo_appendices = []

# If false, no module index is generated.
#texinfo_domain_indices = True

# How to display URL addresses: 'footnote', 'no', or 'inline'.
#texinfo_show_urls = 'footnote'
