# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Unit tests for the utah.provisioning.debs module."""

import os
import shutil
import tempfile
import unittest

from mock import patch

from utah.config import config
from utah.provisioning.exceptions import UTAHProvisioningException
from utah.provisioning.debs import (
    _schema_deb,
    get_client_debs,
)


class TestDebs(unittest.TestCase):

    """Tests the functions of the utah.provisioning.debs module."""

    def setUp(self):
        """Set up a temp directory for test data."""
        self.pkgdir = config.packagedir
        self.tmpdir = tempfile.mkdtemp(prefix='utah_debs')
        config.packagedir = self.tmpdir

        ver = 'FOO'

        class dummy(object):
            def __init__(self):
                self.installedVersion = ver
        self.cache = {'utah': dummy()}

        for pkg in ['common', 'client']:
            fname = 'utah-{}_{}_all.deb'.format(pkg, ver)
            pkg = os.path.join(self.tmpdir, fname)
            with open(pkg, 'w') as f:
                f.write('')

    def tearDown(self):
        """Clean up stuff from the setup function."""
        config.packagedir = self.pkgdir
        shutil.rmtree(self.tmpdir)

    @patch('apt.cache.Cache')
    def test_client_debs(self, cache):
        """Ensure get_client_debs API works."""

        cache.side_effect = [self.cache, self.cache]
        self._setup_schema(2, 4)
        self.assertEqual(len(get_client_debs()), 3)
