# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Module to test our template utility."""

import os
import unittest

from utah.config import config
from utah import template

from tests.common import (  # NOQA
    setUp,     # Used by nosetests
    tearDown,  # Used by nosetests
)


class TestTemplate(unittest.TestCase):

    """Unit test class for our template utility."""

    def setUp(self):
        """Executed before each test_ method is called."""
        with open(os.path.join(config.template_dir, 'tmp.jinja2'), 'w') as f:
            f.write('line1\nfoo={{foo}}')

        # if other tests have run first template.py's initialization may
        # have picked the wrong config.template_dir. This makes it
        # re-initialize
        template.as_buff._env = None

    def test_as_buff(self):
        """minimal test to make sure the template api works."""
        buff = template.as_buff('tmp.jinja2', foo='bar')
        self.assertEqual(buff, 'line1\nfoo=bar')

    def test_write(self):
        """minimal test to make sure the file write api works."""
        self.setUp()
        f = os.path.join(config.template_dir, 'tmp.txt')
        template.write('tmp.jinja2', f, foo='bar')
        with open(f, 'r') as f:
            self.assertEqual(f.read(), 'line1\nfoo=bar')
