# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test virtual machine functionality."""

import libvirt
import unittest

from utah.config import config
from utah.iso import ISO
from utah.provisioning.vm import CustomVM
from utah.timeout import UTAHTimeout


class TestVM(unittest.TestCase):

    """Test VM code."""

    def setUp(self):
        """Create libvirt connection and verify VM is not present."""
        self.vmname = 'utah-unittest'
        self.lv = libvirt.open(config.qemupath)
        with self.assertRaisesRegexp(libvirt.libvirtError, 'Domain not found'):
            self.lv.lookupByName(self.vmname)

    def cleanUp(self):
        """Remove temporary resources."""
        try:
            vm = self.lv.lookupByName(self.vmname)
            vm.destroy()
            vm.undefine()
        except libvirt.libvirtError:
            pass

    def test_vm_cleanup_on_install_failure(self):
        """Verify that a failed install still cleans up the VM."""
        config.installtimeout = 1
        m = CustomVM(image=ISO(), name=self.vmname)
        with self.assertRaises(UTAHTimeout):
            m._create(None)
        with self.assertRaisesRegexp(libvirt.libvirtError, 'Domain not found'):
            self.lv.lookupByName(self.vmname)
