# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Provide UTAH client exceptions."""


class UTAHClientError(Exception):

    """Base class of all exceptions in the client."""

    pass


class BadDir(UTAHClientError):

    """Directory error.

    Raised when some test directory isn't found
    or an error happens when trying to change to it

    """

    pass


class MissingFile(UTAHClientError):

    """Raised when yaml file with metadata about tests cannot be found."""

    pass


class BadMasterRunlist(UTAHClientError):

    """Raised when master runlist isn't in the expected format."""

    pass


class YAMLParsingError(UTAHClientError):

    """Provide more detailed yaml.load exception handling.

    Used to provide the filename and the location
    in which the parsing error happened when calling yaml.load

    """

    pass


class YAMLEmptyFile(UTAHClientError):

    """Raised when a file that was supposed to contain yaml data is empty."""

    pass


class ValidationError(UTAHClientError):

    """Used to provide additional information when schema validation fails."""

    pass
