# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""A probe implementation for eventstat."""

import os
import signal
import subprocess
import time


class _EventStat(object):
    def start(self, outputdir):
        """Start the eventstat binary.

        :return: information needed by the stop method
        :rtype: tuple

        """
        f = open('/dev/null', 'w')
        name = 'eventstat_{}.csv'.format(time.time())
        results = os.path.join(outputdir, name)
        proc = subprocess.Popen(
            ['sudo', 'eventstat', '-C', '-S', '-l', '-r', results], stdout=f)
        return (proc, f, results)

    def stop(self, start_data):
        """Stop the eventstat binary.

        :return: the path the eventstat csv ouput
        :rtype: dict

        """
        proc, f, results = start_data
        proc.send_signal(signal.SIGINT)
        proc.wait()
        f.close()
        return {'results': results}

eventstat = _EventStat()
