# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""A probe implementation for determine information about interrupts."""

import os
import time


class _Interrupts(object):
    @staticmethod
    def _get_count():
        with open('/proc/stat', 'r') as f:
            for l in f.readlines():
                if l.startswith('intr '):
                    return int(l.split(' ', 2)[1])
        return 0

    @staticmethod
    def _get_file(outputdir):
        interrupts = ''
        with open('/proc/interrupts', 'r') as f:
            interrupts = f.read()

        fname = 'interrupts_{}'.format(time.time())
        fname = os.path.join(outputdir, fname)
        with open(fname, 'w') as f:
            f.write(interrupts)
        return fname

    def start(self, outputdir):
        """Gather initial interrupt information.

        :return: information needed by the stop method
        :rtype: tuple

        """
        return (self._get_file(outputdir), time.time(), self._get_count())

    def stop(self, start_data):
        """Grab the final interrupt info and compare to start.

        :return: interrupt rate
        :rtype: dict

        """
        end_count = self._get_count()
        end_time = time.time()
        start_file, start_time, start_count = start_data
        return {
            'total': end_count - start_count,
            'duration': end_time - start_time,
            'rate': (end_count - start_count) / (end_time - start_time),
            'interrupts_start': start_file,
            'interrupts_end': self._get_file(os.path.dirname(start_file)),
        }

interrupts = _Interrupts()
