# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test our battery interface."""


import unittest

from utah.client.probe.battery import battery


class TestBattery(unittest.TestCase):

    """Basic testing of the battery interface."""

    def test_listing(self):
        """Ensure we properly discover the implementations."""
        self.assertTrue('software' in battery.implementations())

    def test_default(self):
        """Make sure battery initialization is initialzed correctly."""
        self.assertIsNotNone(battery.get_data())

    def test_non_default(self):
        """Perform check to see if non-default battery works.

        :returns: nothing - the inner function is confusing pep257

        """
        class dummy(object):
            @staticmethod
            def get_name():
                return 'dummy'

            def get_data(self):
                return {'foo': 'bar'}

        battery._impls[dummy.get_name()] = dummy
        self.assertTrue('dummy' in battery.implementations())

        battery.implementation = dummy.get_name()
        self.assertEquals(battery.get_data()['foo'], 'bar')
