# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the client script."""

import os
import sys
import tempfile
import unittest

from mock import patch

import client

from utah.client.common import ReturnCodes


class TestClient(unittest.TestCase):

    """Test the client script."""

    @patch('client.sys.stderr')
    @patch('utah.client.runner.parse_yaml_file')
    @patch('utah.client.runner.urllib.urlretrieve')
    @patch('utah.client.runner.os.path.isfile')
    @patch('client.url_argument')
    def test_report_not_written_on_invalid_runlist(
            self, url_argument, isfile, urlretrieve, parse_yaml_file, stderr):
        """Test report file is not created on runlist validation failure."""
        output_file = tempfile.mktemp(prefix='utah-', suffix='.yaml')

        # Set mock objects return value
        url_argument.return_value = '<runlist>'
        isfile.return_value = True
        filename = '<local_filename>'
        urlretrieve.return_value = [filename]
        parse_yaml_file.return_value = 'invalid_runlist'

        with self.assertRaises(SystemExit):
            client.main(['-r', '<runlist>', '-o', output_file])
        self.assertFalse(os.path.exists(output_file),
                         'Output file was created: {}'.format(output_file))
        args, kwargs = stderr.write.call_args_list[0]
        self.assertTrue(
            args[0].startswith('Master runlist failed to validate: '
                               "'{}'\n".format(filename)))

    @patch('argparse._sys.stderr')
    def test_invalid_argument_return_code(self, stderr):
        """Test return code value on invalid command line arguments."""
        prog = 'utah'
        sys.argv[0] = prog
        with self.assertRaises(SystemExit) as cm:
            client.main(['--invalid-option'])

        self.assertEqual(cm.exception.code, ReturnCodes.CMD_PARSING_ERROR)
        stderr.write.assert_called_with(
            '{}: error: unrecognized arguments: --invalid-option\n'
            .format(prog))
