# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test our eventstat probe."""

import os
import shutil
import tempfile
import time
import unittest

from utah.client.probe.eventstat import eventstat


class TestEventStat(unittest.TestCase):

    """Basic testing of the eventstat probe."""

    def setUp(self):
        """Create temporary directory for probe output."""
        self.output_dir = tempfile.mkdtemp()

    def tearDown(self):
        """Cleanup artifacts from setUp."""
        shutil.rmtree(self.output_dir)

    @unittest.skipUnless(os.path.exists('/usr/bin/eventstat'), 'need evenstat')
    def test_basic(self):
        """Ensure the eventstat probe can run properly."""
        d = eventstat.start(self.output_dir)
        time.sleep(1)
        d = eventstat.stop(d)
        self.assertIn('results', d)
        self.assertTrue(os.path.exists(d['results']))
