# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Test YAML functionality."""


import unittest
import yaml


class TestYAML(unittest.TestCase):

    """Test YAML processing."""

    def test_parts(self):
        """Test initial YAML processing."""
        content = {}
        content['metadata'] = {
            'runlist': '/tmp/master.run',
            'host': 'Ubuntu 12.04 LTS',
        }
        content['commands'] = [
            {
                'command': 'rm -f blah',
                'stdout': '',
                'stderr': '',
            }
        ]

        enc_data = yaml.dump(content, default_flow_style=False)

        print(enc_data)

        dec_data = yaml.load(enc_data)
        print(content)
        print(dec_data)

    def test_parts_2(self):
        """Test additional YAML processing."""
        content = {
            'file': '/tmp/file'
        }

        extra_args = {
            #'explicit_start': '---',
            #'explicit_end': '...',
        }

        enc_data = yaml.dump(content, default_flow_style=False, **extra_args)

        content = {
            'commands':
            [
                {
                    'size': 100,
                    'perms': 'rwxr-xr-x',
                },
                {
                    'size': 120,
                    'perms': 'rwxr-xr-x',
                },
            ]
        }

        enc_data += yaml.dump(content, default_flow_style=False, **extra_args)

        #enc_data = "---\n{}\n...\n".format(enc_data)

        print(enc_data)

        dec_data = yaml.load(enc_data)
        print(dec_data)

    def test_parts_3(self):
        """Test final YAML processing."""
        extra_args = {}
        content = [
            {
                'file': '/tmp/file',
            },
            [
                {
                    'size': 100,
                    'perms': 'rwxr-xr-x',
                },
                {
                    'size': 120,
                    'perms': 'rwxr-xr-x',
                },
            ]
        ]
        enc_data = yaml.dump(content, default_flow_style=False, **extra_args)
        print(enc_data)
