# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Allow conditional inclusion of experimental features."""

import logging
import os

_features = [
    'PROVISIONED_AUTORUN',
]


class _feature(object):

    """Build up a list of what experimental features are enabled.

    Experimental features can be enabled by the existance of an environment
    variable in the format: UTAH_FEATURE_FOO=<any value>

    """

    def __init__(self):
        for f in _features:
            key = 'UTAH_FEATURE_{}'.format(f)
            setattr(self, f, key in os.environ)

    def log_features(self):
        """Write an info logging message with the state of each feature."""
        buf = 'UTAH Features:'
        for f in _features:
            buf += '\n {}: {}'.format(f, getattr(self, f))
        logging.info(buf)


feature = _feature()
