# Ubuntu Testing Automation Harness
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""UTAH client logger support."""

import os

# normally we do our logging to syslog so that we pick up remote
# logging via syslog. However, when doing local testing or even
# using run_utah_phablet.py with --from-host its nice to log directly
# to STDOUT

if os.environ.get('UTAH_LOGGER', '').lower() == 'stdout':
    import sys

    def log_error(msg):
        print('ERROR: {}'.format(msg))

    def log(msg, crlf=True):
        sys.stdout.write(msg)
        if crlf:
            sys.stdout.write('\n')

else:
    import syslog
    syslog.openlog('utah', 0, syslog.LOG_LOCAL0)

    def log_error(msg):
        syslog.syslog(syslog.LOG_ERR, msg)

    def log(msg, crlf=True):
        syslog.syslog(msg)
