# Ubuntu Testing Automation Harness
# Copyright 2012 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""utah.provisioning.baremetal"""


import os

from utah.exceptions import UTAHException
from utah.provisioning.baremetal.inventory import (
    ManualBaremetalSQLiteInventory
)


MISSING = []
try:
    from utah.provisioning.baremetal.bamboofeeder import BambooFeederMachine
except ImportError:
    MISSING.append('bamboofeeder')
try:
    from utah.provisioning.baremetal.cobbler import CobblerMachine
except ImportError:
    MISSING.append('cobbler')


def get_baremetal(arch, **kw):
    """Return a Machine object with the passed in arch and arguments.

    :param arch: Architecture of machine (mainly used for ARM or not ARM)
    :type arch: str
    :param kw: All other parameters are passed to the Machine constructor
    :type kw: dict

    :returns: Appropriately constructed Machine object
    :rtype: object

    """
    if 'arm' in arch:
        if 'bamboofeeder' in MISSING:
            raise UTAHException(
                'utah-bamboofeeder package needed for panda boards')
        inventory = ManualBaremetalSQLiteInventory(
            db=os.path.join('~', '.utah-bamboofeeder-inventory'),
            lockfile=os.path.join('~', '.utah-bamboofeeder-lock'))
        kw['machinetype'] = BambooFeederMachine
    else:
        if 'cobbler' in MISSING:
            raise UTAHException(
                'utah-cobbler package needed for this machine type')
        inventory = ManualBaremetalSQLiteInventory()
        kw['machinetype'] = CobblerMachine
    return inventory.request(**kw)
